==> selenium-selenium-4.31.0.gh.tar.gz: selenium-selenium-4.31.0/dotnet/src/webdriver/NetworkAuthenticationHandler.cs <==
// <copyright file="NetworkAuthenticationHandler.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System;
using System.Diagnostics.CodeAnalysis;

namespace OpenQA.Selenium
{
    /// <summary>
    /// Allows a user to supply authentication information for network requests.
    /// </summary>
    public class NetworkAuthenticationHandler
    {
        /// <summary>
        /// Gets or sets a function that takes a <see cref="Uri"/> object, and returns a
        /// value indicating whether the supplied URI matches the specified criteria.
        /// </summary>
        [DisallowNull]
        public Func<Uri, bool>? UriMatcher { get; set; }

        /// <summary>
        /// Gets or sets the credentials to use when responding to an authentication request
        /// that matches the specified criteria.
        /// </summary>
        [DisallowNull]
        public ICredentials? Credentials { get; set; }
    }
}

==> selenium-selenium-4.35.0.gh.tar.gz: selenium-selenium-4.35.0/dotnet/src/webdriver/NetworkAuthenticationHandler.cs <==
// <copyright file="NetworkAuthenticationHandler.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System;
using System.Diagnostics.CodeAnalysis;

namespace OpenQA.Selenium;

/// <summary>
/// Allows a user to supply authentication information for network requests.
/// </summary>
public class NetworkAuthenticationHandler
{
    /// <summary>
    /// Gets or sets a function that takes a <see cref="Uri"/> object, and returns a
    /// value indicating whether the supplied URI matches the specified criteria.
    /// </summary>
    [DisallowNull]
    public Func<Uri, bool>? UriMatcher { get; set; }

    /// <summary>
    /// Gets or sets the credentials to use when responding to an authentication request
    /// that matches the specified criteria.
    /// </summary>
    [DisallowNull]
    public ICredentials? Credentials { get; set; }
}
